Subject: [bug#65409] [PATCH] gnu: gnubg: Update to 1.07.001.

From: [email-masked]
Date: Sun, 20 Aug 2023 20:41:59 +0800

From: 宋文武 <[email-masked]>

* gnu/packages/games.scm (gnubg): Update to 1.07.001.
---
 gnu/packages/games.scm | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/gnu/packages/games.scm b/gnu/packages/games.scm
index a5fa19fc20..03e1afffe0 100644
--- a/gnu/packages/games.scm
+++ b/gnu/packages/games.scm
@@ -2011,7 +2011,7 @@ (define-public gnome-chess
 (define-public gnubg
   (package
     (name "gnubg")
-    (version "1.06.002")
+    (version "1.07.001")
     (source
      (origin
        (method url-fetch)
@@ -2019,10 +2019,10 @@ (define-public gnubg
                            version "-sources.tar.gz"))
        (sha256
         (base32
-         "11xwhcli1h12k6rnhhyq4jphzrhfik7i8ah3k32pqw803460n6yf"))))
+         "07l2srlm05c99l4pppba8l54bnh000ns2rih5h8rzbcw84lrffbj"))))
     (build-system gnu-build-system)
     (inputs (list ;; XXX: Build with an older Pango for 'pango_font_get_hb_font' and
                   ;; 'pango_coverage_get_type'.  Try removing this for versions > 1.06.002.
                   pango-1.42
                   glib
                   readline
@@ -2019,10 +2019,10 @@ (define-public gnubg
     (build-system gnu-build-system)
     (inputs (list ;; XXX: Build with an older Pango for 'pango_font_get_hb_font' and
-                  ;; 'pango_coverage_get_type'.  Try removing this for versions > 1.06.002.
+                  ;; 'pango_coverage_get_type'.  Try removing this for versions > 1.07.001.
                   pango-1.42
                   glib

base-commit: ad5e4fe54a66c725dc03dedebf8e5c65723ccb74
-- 
2.41.0